#!/bin/ksh
##############################################################
#
# System Automation Application Manager hardware adapter 
# control script
#
# Input:
#       $1      action (<start|stop|status>)
#       $2      eez install directory
#
# Purpose  : Use this shell script to start, stop and monitor the 
#            hardware adapter
#
#
# Returns  :	 General:
#                0 - Success
#                1 - Error
#
#                As result of -status:
#                0 - Unknown
#                1 - Online
#                2 - Offline
#                3 - Failed Offline
#                5-  Pending Online
#
##############################################################
#
# init section
# 
#
# determine os name in order to set rc's
# rc for the status command
UNKNOWN=0
ONLINE=1
OFFLINE=2
FAILED_OFFLINE=3
PENDING_ONLINE=5

Action=${1:-status}
INST_HOME=$2/bin

export PATH=$PATH:/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin:${NA_HOME}/bin

case ${Action} in
        start)
                logger -i -p info -t $0 "hardware adapter starting..."
                ${INST_HOME}/eezhwadapter.sh -START >/dev/null 2>&1
                RC=$?
                # rc 2 means hwa is starting -- okay
                if [[ $RC -eq 2 ]]; then
                  RC=0
                fi
                logger -i -p info -t $0 "hardware adapter start rc: ${RC}"
                ;;
        stop)
                logger -i -p info -t $0 "hardware adapter stopping..."
                ${INST_HOME}/eezhwadapter.sh -SHUTD >/dev/null 2>&1
                RC=$?
                if [[ $RC -eq 0 ]]; then
                  logger -i -p info -t $0 "hardware adapter stop rc: ${RC}"
                else
                  logger -i -p info -t $0 "hardware adapter stop rc: ${RC}"
                  HWA_pid=`ps -ef | grep "eez.hwadapter.properties" | grep -v grep | awk '{print $2}'`
                  kill -9 ${HWA_pid} > /dev/null 2>&1
                  logger -i -p info -t $0 "hardware adapter (pid ${HWA_pid}) killed."
                  RC=0
                fi
                ;;
        status)
                ${INST_HOME}/eezhwadapter.sh -MONITOR >/dev/null 2>&1
                rc=$?
                case ${rc} in
                     0) RC=${ONLINE} ;;
                     2) RC=${PENDING_ONLINE} ;;
                     6) RC=${OFFLINE} ;;
                     10) RC=${FAILED_OFFLINE} ;;
                     *) RC=${UNKNOWN} ;;
                esac
                ;;
        *)
                logger -i -p info -t $0 "Error: Incorrect parameter >${Action}<"
                RC=${UNKNOWN}
                ;;
esac

exit ${RC}

